@@ -2,9 +2,9 @@
 # This code is part of the MAterials Simulation Toolkit (MAST)
 # 
 # Maintainer: Tam Mayeshiba
-# Last updated: 2014-05-12 by Zhewen Song
+# Last updated: 2014-06-13 by Zhewen Song
 ##############################################################
-import os
+import os, re
 import numpy as np
 import logging
 import shutil
@@ -14,7 +14,6 @@ from pymatgen.core.structure import Lattice
 from pymatgen.core.structure_modifier import StructureEditor
 from pymatgen.util.coord_utils import find_in_coord_list
 from pymatgen.io.vaspio import Poscar
-from MAST.utility import InputOptions
 from MAST.utility import MASTObj
 from MAST.utility import MASTError
 from MAST.utility import Metadata
@@ -31,10 +30,10 @@ class ChopIngredient(BaseIngredient):
             'name' : (str, str(), 'Name of directory'),
             'program': (str, str(), 'Program, e.g. "vasp"'),
             'program_keys': (dict, dict(), 'Dictionary of program keywords'),
-            'structure': (Structure, None, 'Pymatgen Structure object')
+            'structure': (Structure, None, 'Pymatgen Structure object'),
             }
         BaseIngredient.__init__(self, allowed_keys, **kwargs)
-
+        
     def _fullpath_childname(self, childname):
         """Get full path of the child directory.
             Args: 
@@ -367,7 +366,8 @@ class ChopIngredient(BaseIngredient):
             if os.path.isfile(allowed_file):
                 allowed_list = self._get_allowed_keywords(allowed_file, upperkey)
             else:
-                allowedpath = os.path.join(dirutil.get_mast_control_path(),'programkeys',allowed_file)
+                allowedpath = os.path.join(dirutil.get_mast_install_path(),
+                            'ingredients','programkeys',allowed_file)
                 allowed_list = self._get_allowed_keywords(allowedpath, upperkey)
         for key, value in self.keywords['program_keys'].iteritems():
             if not key[0:5] == "mast_":
@@ -738,7 +738,9 @@ class ChopIngredient(BaseIngredient):
             self.logger.warning("No parent structure detected for induce defect ingredient %s. Using initial structure of the recipe." % self.keywords['name'])
         scalingsize = self.metafile.read_data('scaling_size')
         if scalingsize == None: scalingsize = '1 1 1'
-        else: scalingsize = ' '.join(scalingsize.split('x'))
+        elif '[' and ']' in scalingsize:
+            scalingsize = scalingsize.split('[')[1].split(']')[0]
+        else: raise MASTError(self.__class__.__name__, "Error in scaling size for the ingredient %s" % self.keywords['name'])
         scalextend = StructureExtensions(struc_work1=base_structure, scaling_size=scalingsize, name=self.keywords['name'])
         scaled = scalextend.scale_structure()
         self.checker.write_final_structure_file(scaled)
@@ -751,8 +753,10 @@ class ChopIngredient(BaseIngredient):
             base_structure = self.keywords['structure'].copy()
             self.logger.warning("No parent structure detected for induce defect ingredient %s. Using initial structure of the recipe." % self.keywords['name'])
         scalingsize = self.metafile.read_data('scaling_size')
-        if scalingsize == None: scalingsize = '1 1 1'
-        else: scalingsize = ' '.join(scalingsize.split('x'))
+        if scalingsize == None: scalingsize = '1,1,1'
+        elif '[' and ']' in scalingsize:
+            scalingsize = scalingsize.split('[')[1].split(']')[0]        
+        else: raise MASTError(self.__class__.__name__, "Error in scaling size for the ingredient %s"%self.keywords['name'])        
         defect = self.keywords['program_keys']['mast_defect_settings']
         scaled = base_structure.copy()
         for key in defect:
@@ -1048,3 +1052,4 @@ class ChopIngredient(BaseIngredient):
         childname = self._fullpath_childname(childname)
         self.checker.forward_final_structure_file(childname)
         self.checker.softlink_wavefunction_file(childname)
+
