@@ -12,6 +12,7 @@ EMAX
 EMIN
 ENCUT
 GGA
+HFSCREEN
 I_CONSTRAINED_M
 IALGO
 IBRION
@@ -40,6 +41,7 @@ LDAUPRINT
 LDAUTYPE
 LDAUU
 LELF
+LHFCALC
 LMAXMIX
 LNONCOLLINEAR
 LORBIT
@@ -54,6 +56,7 @@ MAGMOM
 NBANDS
 NBLK
 NBLOCK
+NEDOS
 NELECT
 NELM
 NELMDL
@@ -73,6 +76,7 @@ NWRITE
 POMASS
 POTIM
 PREC
+PRECFOCK
 ROPT
 RWIGS
 SIGMA
