@@ -1,6 +1,8 @@
 from MAST.structopt.generate import gen_pop_box, gen_pop_sphere
-from MAST.structopt.generate.Individual import Individual
-
+try:
+    from MAST.structopt.generate.Individual import Individual
+except NameError:
+    print "NOTE: ASE is not installed. ASE must be installed for Structopt Individual.py to work correctly."
 def get_crystal_indiv(Optimizer):
     """
     Function to generate an structopt Individual class object containing a crystal structure.
